import { useState } from "react";
import { Link } from "wouter";
import { Heart } from "lucide-react";
import { apiRequest, queryClient } from "@/lib/queryClient";
import { useToast } from "@/hooks/use-toast";
import { Card, CardContent } from "@/components/ui/card";
import { Button } from "@/components/ui/button";
import { formatDistanceToNow } from 'date-fns';
import { fr } from 'date-fns/locale';
import { useQuery } from "@tanstack/react-query";

interface ListingCardProps {
  listing: {
    id: number;
    title: string;
    price: number | null;
    description: string;
    location: string;
    createdAt: string;
    isUrgent?: boolean;
    primaryImage?: string | null;
    userId: number;
  };
}

const ListingCard = ({ listing }: ListingCardProps) => {
  const { toast } = useToast();
  const [isFavorite, setIsFavorite] = useState(false);
  
  // Check if user is logged in
  const { data: userData } = useQuery<{ user: any }>({
    queryKey: ['/api/auth/current-user'],
    retry: false,
  });
  
  const isLoggedIn = !!userData?.user;
  
  // Handle favorite toggle
  const toggleFavorite = async (e: React.MouseEvent) => {
    e.preventDefault();
    e.stopPropagation();
    
    if (!isLoggedIn) {
      toast({
        title: "Connexion requise",
        description: "Veuillez vous connecter pour ajouter des favoris",
        variant: "destructive",
      });
      return;
    }
    
    try {
      if (isFavorite) {
        await apiRequest('DELETE', `/api/favorites/${listing.id}`, {});
        setIsFavorite(false);
      } else {
        await apiRequest('POST', '/api/favorites', { listingId: listing.id });
        setIsFavorite(true);
      }
      
      // Invalidate favorites query
      queryClient.invalidateQueries({ queryKey: ['/api/favorites'] });
      
    } catch (error) {
      toast({
        title: "Erreur",
        description: "Une erreur est survenue. Veuillez réessayer.",
        variant: "destructive",
      });
    }
  };
  
  // Format date
  const formattedDate = formatDistanceToNow(new Date(listing.createdAt), {
    addSuffix: true,
    locale: fr,
  });
  
  return (
    <Card className="overflow-hidden transition-transform hover:shadow-lg hover:translate-y-[-5px] border-teal-200">
      <Link href={`/listings/${listing.id}`}>
        <div className="relative pb-[75%]">
          {listing.primaryImage ? (
            <img 
              src={listing.primaryImage} 
              alt={listing.title} 
              className="absolute inset-0 w-full h-full object-cover"
            />
          ) : (
            <div className="absolute inset-0 w-full h-full bg-teal-50 flex items-center justify-center">
              <span className="text-teal-400">Pas d'image</span>
            </div>
          )}
          
          {listing.isUrgent && (
            <div className="absolute top-0 left-0 mt-2 ml-2">
              <span className="bg-amber-500 text-white text-xs font-bold px-2 py-1 rounded">URGENT</span>
            </div>
          )}
          
          <Button
            variant="ghost"
            size="icon"
            className="absolute top-0 right-0 mt-2 mr-2 bg-white/80 hover:bg-white rounded-full p-2 text-teal-600 hover:text-teal-800"
            onClick={toggleFavorite}
          >
            <Heart className={`h-5 w-5 ${isFavorite ? 'fill-teal-600' : ''}`} />
          </Button>
        </div>
        
        <CardContent className="p-4">
          <div className="flex justify-between">
            <h3 className="font-bold text-lg mb-1 line-clamp-1 text-teal-800">{listing.title}</h3>
            <span className="font-bold text-teal-600 text-lg">
              {listing.price ? `${listing.price.toLocaleString('fr-FR')} €` : 'Prix non défini'}
            </span>
          </div>
          
          <p className="text-sm text-gray-600 mb-2 line-clamp-2">{listing.description}</p>
          
          <div className="flex items-center text-sm text-teal-600">
            <i className="fas fa-map-marker-alt mr-1"></i>
            <span>{listing.location}</span>
          </div>
          
          <div className="flex items-center justify-between mt-2">
            <span className="text-xs text-teal-500">{formattedDate}</span>
            <span className="text-xs bg-teal-100 text-teal-800 px-2 py-0.5 rounded-full">
              {/* Placeholder for pro/particulier status */}
              Particulier
            </span>
          </div>
        </CardContent>
      </Link>
    </Card>
  );
};

export default ListingCard;
